**10. Acknowledgement**
========================

If you use PowNet for your research, please cite the following paper:

Chowdhury, A.F.M.K., Kern, J., Dang, T.D. and Galelli, S.,
2020. `PowNet: A Network-Constrained Unit Commitment/Economic Dispatch
Model for Large-Scale Power Systems
Analysis <http://doi.org/10.5334/jors.302>`_. Journal of Open Research
Software, 8(1), p.5.
